(function ($, Drupal, drupalSettings) {
  'use strict';

  /**
   * Enhanced Component Field Admin behavior
   */
  Drupal.behaviors.componentFieldAdmin = {
    attach: function (context, settings) {
      // Admin overview enhancements
      $('.component-field-overview', context).once('component-field-admin').each(function () {
        initializeAdminOverview($(this));
      });

      // Component management
      $('.component-field-admin-component-item', context).once('component-field-admin-item').each(function () {
        initializeAdminComponentItem($(this));
      });

      function initializeAdminOverview($overview) {
        // Search functionality
        var $searchField = $overview.find('.component-field-search');
        if ($searchField.length) {
          $searchField.on('keyup', function () {
            filterComponents($(this).val());
          });
        }

        // Filter by type
        var $typeFilter = $overview.find('.component-field-type-filter');
        if ($typeFilter.length) {
          $typeFilter.on('change', function () {
            filterComponentsByType($(this).val());
          });
        }

        // Batch actions
        $overview.find('.component-field-batch-refresh').on('click', function (e) {
          e.preventDefault();
          batchRefreshComponents();
        });
      }

      function initializeAdminComponentItem($item) {
        // Component details toggle
        $item.find('.component-field-details-toggle').on('click', function (e) {
          e.preventDefault();
          $item.find('.component-field-details').slideToggle();
        });

        // Individual refresh
        $item.find('.component-field-refresh').on('click', function (e) {
          e.preventDefault();
          refreshSingleComponent($item.data('component-name'));
        });
      }

      function filterComponents(searchTerm) {
        var $items = $('.component-field-admin-component-item');

        if (!searchTerm) {
          $items.show();
          return;
        }

        $items.each(function () {
          var $item = $(this);
          var text = $item.text().toLowerCase();
          if (text.indexOf(searchTerm.toLowerCase()) !== -1) {
            $item.show();
          } else {
            $item.hide();
          }
        });
      }

      function filterComponentsByType(type) {
        var $items = $('.component-field-admin-component-item');

        if (!type || type === 'all') {
          $items.show();
          return;
        }

        $items.each(function () {
          var $item = $(this);
          if ($item.data('component-type') === type) {
            $item.show();
          } else {
            $item.hide();
          }
        });
      }

      function batchRefreshComponents() {
        var $button = $('.component-field-batch-refresh');
        var originalText = $button.text();

        $button.text('Refreshing...').prop('disabled', TRUE);

        $.post('/admin/structure/component-field/refresh')
          .done(function () {
            location.reload();
          })
          .fail(function () {
            alert('Failed to refresh components');
          })
          .always(function () {
            $button.text(originalText).prop('disabled', FALSE);
          });
      }

      function refreshSingleComponent(componentName) {
        // Individual component refresh logic
        console.log('Refreshing component:', componentName);
      }
    }
  };

})(jQuery, Drupal, drupalSettings);